@@ -27,7 +27,8 @@ function(MEC, fcol=gray(0.90), fcolback="white", ALIM = c(-1, -1, +1, +1))
   
   POK = list(x=PLS$Px, y =PLS$Py)
   
-  kin = inpoly(pax$x, pax$y,POK)
+  ###  OLD, does not work: kin = inpoly(pax$x, pax$y,POK)
+ kin = inout(cbind(pax$x, pax$y) ,cbind(PLS$Px, y =PLS$Py), bound=TRUE)
 
   if(kin==0)
     {
